# zxx

* 北京大学政信社（政信信）女足开发的 Python 库，主要用于剪辑比赛集锦。 / A Python package developed by “Zheng-Xin-She” (formerly “Zheng-Xin-Xin”) Women’s Football Team at Peking University, mainly used for editing game highlights.
* 点击[此处](https://github.com/PKU-Zyf/zxx)前往 `zxx` 的 GitHub 主页。您可以在 `zxx_example_code` 文件夹查看示例代码。 / Click [here](https://github.com/PKU-Zyf/zxx) to go to the GitHub homepage of  `zxx`. You can check example code in the  `zxx_example_code` folder.
* 点击[此处](https://pypi.org/project/zxx)前往 `zxx` 的 PyPI 主页。 / Click [here](https://pypi.org/project/zxx) to go to the PyPI homepage of `zxx`.
* 安装 / To install: `pip install zxx`.
* 更新 / To update: `pip install --upgrade zxx` / `pip install -U zxx`.
* 注意：由于 `zxx` 库依赖 `moviepy` 库进行视频编辑，而 `moviepy` 的运行需要首先自行安装 ImageMagick。因此**在使用 `zxx` 库前，也需要先在电脑上手动安装 ImageMagick**，才能正常使用。安装方式请参考[此处](https://www.imagemagick.org/script/download.php)。 / Caution: Since `zxx` relies on `moviepy` for video editing, and you need to install ImageMagick first to run `moviepy` properly, **you also need to install ImageMagick manually on your computer before you can use `zxx`**. Click [here](https://www.imagemagick.org/script/download.php) for the installation tips.

## 更新日志 Update Logs

* 0.1.0 (2022-11-07)
  * 第一次正式发布。 / The first release.
* 0.2.0 (2023-04-03)
  * 全面修改运行逻辑。 / An entire modification.
* 1.0.0 (2024-10-23)
  * 修复了一些 bug，简化了使用逻辑，添加了详细的文档字符串（使用说明）。 / Fixed some bugs, simplified the usage, and added detailed docstrings.
* 1.0.1 (2024-10-23)
  * 修改了一些文字错误，增加了示例代码。 / Fixed some typos and added example code.
* 1.1.0 (2025-07-30)
  * 增加了修改主客队信息的 change_match_info() 方法。 / Add `change_match_info()` method.
  * 增加了多线程导出集锦的选项。 / Add multi-threading exporting option.
